
# Speed and Performance
This following figure examines relation between speed and performance on the Scandinavian Embedding Benchmark. API models are not included as speeds may vary.


<iframe title="Speed x Performance" aria-label="Scatter Plot" id="datawrapper-chart-oXdUJ" src="https://datawrapper.dwcdn.net/oXdUJ/17/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="1325" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r=0;r<e.length;r++)if(e[r].contentWindow===a.source){var i=a.data["datawrapper-height"][t]+"px";e[r].style.height=i}}}))}();
</script>